macro_rules! load {
() => { ... };
($title:expr) => { ... };
}Expand description
Include the generated asset manifest and construct a MemoryServe struct.
macro_rules! load {
() => { ... };
($title:expr) => { ... };
}Include the generated asset manifest and construct a MemoryServe struct.